@@ -1,6 +1,6 @@
 #![deny(missing_docs)]
 #![warn(rust_2018_idioms)]
-#![doc(html_root_url = "https://docs.rs/tcp-stream/0.23.0/")]
+#![doc(html_root_url = "https://docs.rs/tcp-stream/0.23.1/")]
 
 //! # std::net::TCP stream on steroids
 //!
@@ -332,7 +332,7 @@ fn into_rustls_common(
         c.add_parsable_certificates(&certs);
     }
     let connector = if let Some(identity) = config.identity {
-        let pfx = pkcs_12::PFX::parse(identity.der).map_err(io::Error::from)?;
+        let pfx = p12::PFX::parse(identity.der).map_err(io::Error::from)?;
         let key = if let Some(key) = pfx
             .key_bags(identity.password)
             .map_err(io::Error::from)?
